@@ -51,13 +51,17 @@
 #include "BeagleWksDBParser.hxx"
 #include "BeagleWksDRParser.hxx"
 #include "BeagleWksSSParser.hxx"
+#include "CanvasParser.hxx"
+#include "Canvas5Parser.hxx"
 #include "ClarisDrawParser.hxx"
 #include "ClarisWksParser.hxx"
 #include "ClarisWksBMParser.hxx"
 #include "ClarisWksPRParser.hxx"
 #include "ClarisWksSSParser.hxx"
+#include "CorelPainterParser.hxx"
 #include "CricketDrawParser.hxx"
 #include "DocMkrParser.hxx"
+#include "DrawTableParser.hxx"
 #include "EDocParser.hxx"
 #include "FreeHandParser.hxx"
 #include "FullWrtParser.hxx"
@@ -68,6 +72,8 @@
 #include "GreatWksSSParser.hxx"
 #include "HanMacWrdJParser.hxx"
 #include "HanMacWrdKParser.hxx"
+#include "JazzSSParser.hxx"
+#include "JazzWriterParser.hxx"
 #include "LightWayTxtParser.hxx"
 #include "MacDocParser.hxx"
 #include "MacDraftParser.hxx"
@@ -88,6 +94,7 @@
 #include "MsWksSSParser.hxx"
 #include "MsWrd1Parser.hxx"
 #include "MsWrdParser.hxx"
+#include "MultiplanParser.hxx"
 #include "NisusWrtParser.hxx"
 #include "PixelPaintParser.hxx"
 #include "PowerPoint1Parser.hxx"
@@ -95,6 +102,7 @@
 #include "PowerPoint7Parser.hxx"
 #include "RagTimeParser.hxx"
 #include "RagTime5Parser.hxx"
+#include "RagTime5SSParser.hxx"
 #include "StyleParser.hxx"
 #include "SuperPaintParser.hxx"
 #include "TeachTxtParser.hxx"
@@ -106,12 +114,12 @@
 /** small namespace use to define private class/method used by MWAWDocument */
 namespace MWAWDocumentInternal
 {
-shared_ptr<MWAWGraphicParser> getGraphicParserFromHeader(MWAWInputStreamPtr &input, MWAWRSRCParserPtr rsrcParser, MWAWHeader *header);
-shared_ptr<MWAWPresentationParser> getPresentationParserFromHeader(MWAWInputStreamPtr &input, MWAWRSRCParserPtr rsrcParser, MWAWHeader *header);
-shared_ptr<MWAWSpreadsheetParser> getSpreadsheetParserFromHeader(MWAWInputStreamPtr &input, MWAWRSRCParserPtr rsrcParser, MWAWHeader *header);
-shared_ptr<MWAWTextParser> getTextParserFromHeader(MWAWInputStreamPtr &input, MWAWRSRCParserPtr rsrcParser, MWAWHeader *header);
-MWAWHeader *getHeader(MWAWInputStreamPtr &input, MWAWRSRCParserPtr rsrcParser, bool strict);
-bool checkBasicMacHeader(MWAWInputStreamPtr &input, MWAWRSRCParserPtr rsrcParser, MWAWHeader &header, bool strict);
+std::shared_ptr<MWAWGraphicParser> getGraphicParserFromHeader(MWAWInputStreamPtr &input, MWAWRSRCParserPtr const &rsrcParser, MWAWHeader *header);
+std::shared_ptr<MWAWPresentationParser> getPresentationParserFromHeader(MWAWInputStreamPtr &input, MWAWRSRCParserPtr const &rsrcParser, MWAWHeader *header);
+std::shared_ptr<MWAWSpreadsheetParser> getSpreadsheetParserFromHeader(MWAWInputStreamPtr &input, MWAWRSRCParserPtr const &rsrcParser, MWAWHeader *header);
+std::shared_ptr<MWAWTextParser> getTextParserFromHeader(MWAWInputStreamPtr &input, MWAWRSRCParserPtr const &rsrcParser, MWAWHeader *header);
+MWAWHeader *getHeader(MWAWInputStreamPtr &input, MWAWRSRCParserPtr const &rsrcParser, bool strict);
+bool checkBasicMacHeader(MWAWInputStreamPtr &input, MWAWRSRCParserPtr const &rsrcParser, MWAWHeader &header, bool strict);
 }
 
 MWAWDocument::Confidence MWAWDocument::isFileFormatSupported(librevenge::RVNGInputStream *input,  MWAWDocument::Type &type, Kind &kind)
@@ -127,10 +135,10 @@ try
 
   MWAWInputStreamPtr ip(new MWAWInputStream(input, false, true));
   MWAWInputStreamPtr rsrc=ip->getResourceForkStream();
-  shared_ptr<MWAWRSRCParser> rsrcParser;
+  std::shared_ptr<MWAWRSRCParser> rsrcParser;
   if (rsrc)
     rsrcParser.reset(new MWAWRSRCParser(rsrc));
-  shared_ptr<MWAWHeader> header;
+  std::shared_ptr<MWAWHeader> header;
 #ifdef DEBUG
   header.reset(MWAWDocumentInternal::getHeader(ip, rsrcParser, false));
 #else
@@ -147,11 +155,14 @@ try
   case MWAW_T_ACTA:
   case MWAW_T_APPLEPICT:
   case MWAW_T_BEAGLEWORKS:
+  case MWAW_T_CANVAS:
   case MWAW_T_CLARISDRAW:
   case MWAW_T_CLARISRESOLVE:
   case MWAW_T_CLARISWORKS:
+  case MWAW_T_CORELPAINTER:
   case MWAW_T_CRICKETDRAW:
   case MWAW_T_DOCMAKER:
+  case MWAW_T_DRAWINGTABLE:
   case MWAW_T_EDOC:
   case MWAW_T_FREEHAND:
   case MWAW_T_FULLPAINT:
@@ -160,6 +171,7 @@ try
   case MWAW_T_HANMACWORDJ:
   case MWAW_T_HANMACWORDK:
   case MWAW_T_LIGHTWAYTEXT:
+  case MWAW_T_JAZZLOTUS:
   case MWAW_T_MACDOC:
   case MWAW_T_MACDRAFT:
   case MWAW_T_MACDRAW:
@@ -172,6 +184,7 @@ try
   case MWAW_T_MINDWRITE:
   case MWAW_T_MORE:
   case MWAW_T_MOUSEWRITE:
+  case MWAW_T_MICROSOFTMULTIPLAN:
   case MWAW_T_MICROSOFTWORD:
   case MWAW_T_MICROSOFTWORKS:
   case MWAW_T_NISUSWRITER:
@@ -185,10 +198,10 @@ try
   case MWAW_T_WINGZ:
   case MWAW_T_WRITENOW:
   case MWAW_T_WRITERPLUS:
+  case MWAW_T_XPRESS:
   case MWAW_T_ZWRITE:
     confidence = MWAW_C_EXCELLENT;
     break;
-
   case MWAW_T_ADOBEILLUSTRATOR:
   case MWAW_T_DBASE:
   case MWAW_T_FAMILYTREEMAKER:
@@ -199,16 +212,31 @@ try
   case MWAW_T_INFOGENIE:
   case MWAW_T_KALEIDAGRAPH:
   case MWAW_T_MICROSOFTFILE:
-  case MWAW_T_MICROSOFTMULTIPLAN:
   case MWAW_T_OVERVUE:
   case MWAW_T_PAGEMAKER:
   case MWAW_T_READYSETGO:
   case MWAW_T_SYMPOSIUM:
   case MWAW_T_TRAPEZE:
-  case MWAW_T_XPRESS:
   case MWAW_T_4DIMENSION:
 
-  case MWAW_T_RESERVED9:
+  case MWAW_T_RESERVED13:
+  case MWAW_T_RESERVED14:
+  case MWAW_T_RESERVED15:
+  case MWAW_T_RESERVED16:
+  case MWAW_T_RESERVED17:
+  case MWAW_T_RESERVED18:
+  case MWAW_T_RESERVED19:
+  case MWAW_T_RESERVED20:
+  case MWAW_T_RESERVED21:
+  case MWAW_T_RESERVED22:
+  case MWAW_T_RESERVED23:
+  case MWAW_T_RESERVED24:
+  case MWAW_T_RESERVED25:
+  case MWAW_T_RESERVED26:
+  case MWAW_T_RESERVED27:
+  case MWAW_T_RESERVED28:
+  case MWAW_T_RESERVED29:
+
   case MWAW_T_UNKNOWN:
 #if !defined(__clang__)
   default:
@@ -234,17 +262,17 @@ try
 
   MWAWInputStreamPtr ip(new MWAWInputStream(input, false, true));
   MWAWInputStreamPtr rsrc=ip->getResourceForkStream();
-  shared_ptr<MWAWRSRCParser> rsrcParser;
+  std::shared_ptr<MWAWRSRCParser> rsrcParser;
   if (rsrc) {
     rsrcParser.reset(new MWAWRSRCParser(rsrc));
     rsrcParser->setAsciiName("RSRC");
     rsrcParser->parse();
   }
-  shared_ptr<MWAWHeader> header(MWAWDocumentInternal::getHeader(ip, rsrcParser, false));
+  std::shared_ptr<MWAWHeader> header(MWAWDocumentInternal::getHeader(ip, rsrcParser, false));
 
   if (!header.get()) return MWAW_R_UNKNOWN_ERROR;
 
-  shared_ptr<MWAWGraphicParser> parser=MWAWDocumentInternal::getGraphicParserFromHeader(ip, rsrcParser, header.get());
+  auto parser=MWAWDocumentInternal::getGraphicParserFromHeader(ip, rsrcParser, header.get());
   if (!parser) return MWAW_R_UNKNOWN_ERROR;
   parser->parse(documentInterface);
 
@@ -275,17 +303,17 @@ try
 
   MWAWInputStreamPtr ip(new MWAWInputStream(input, false, true));
   MWAWInputStreamPtr rsrc=ip->getResourceForkStream();
-  shared_ptr<MWAWRSRCParser> rsrcParser;
+  std::shared_ptr<MWAWRSRCParser> rsrcParser;
   if (rsrc) {
     rsrcParser.reset(new MWAWRSRCParser(rsrc));
     rsrcParser->setAsciiName("RSRC");
     rsrcParser->parse();
   }
-  shared_ptr<MWAWHeader> header(MWAWDocumentInternal::getHeader(ip, rsrcParser, false));
+  std::shared_ptr<MWAWHeader> header(MWAWDocumentInternal::getHeader(ip, rsrcParser, false));
 
   if (!header.get()) return MWAW_R_UNKNOWN_ERROR;
 
-  shared_ptr<MWAWPresentationParser> parser=MWAWDocumentInternal::getPresentationParserFromHeader(ip, rsrcParser, header.get());
+  auto parser=MWAWDocumentInternal::getPresentationParserFromHeader(ip, rsrcParser, header.get());
   if (!parser) return MWAW_R_UNKNOWN_ERROR;
   parser->parse(documentInterface);
 
@@ -316,17 +344,17 @@ try
 
   MWAWInputStreamPtr ip(new MWAWInputStream(input, false, true));
   MWAWInputStreamPtr rsrc=ip->getResourceForkStream();
-  shared_ptr<MWAWRSRCParser> rsrcParser;
+  std::shared_ptr<MWAWRSRCParser> rsrcParser;
   if (rsrc) {
     rsrcParser.reset(new MWAWRSRCParser(rsrc));
     rsrcParser->setAsciiName("RSRC");
     rsrcParser->parse();
   }
-  shared_ptr<MWAWHeader> header(MWAWDocumentInternal::getHeader(ip, rsrcParser, false));
+  std::shared_ptr<MWAWHeader> header(MWAWDocumentInternal::getHeader(ip, rsrcParser, false));
 
   if (!header.get()) return MWAW_R_UNKNOWN_ERROR;
 
-  shared_ptr<MWAWSpreadsheetParser> parser=MWAWDocumentInternal::getSpreadsheetParserFromHeader(ip, rsrcParser, header.get());
+  auto parser=MWAWDocumentInternal::getSpreadsheetParserFromHeader(ip, rsrcParser, header.get());
   if (!parser) return MWAW_R_UNKNOWN_ERROR;
   parser->parse(documentInterface);
 
@@ -357,17 +385,17 @@ try
 
   MWAWInputStreamPtr ip(new MWAWInputStream(input, false, true));
   MWAWInputStreamPtr rsrc=ip->getResourceForkStream();
-  shared_ptr<MWAWRSRCParser> rsrcParser;
+  std::shared_ptr<MWAWRSRCParser> rsrcParser;
   if (rsrc) {
     rsrcParser.reset(new MWAWRSRCParser(rsrc));
     rsrcParser->setAsciiName("RSRC");
     rsrcParser->parse();
   }
-  shared_ptr<MWAWHeader> header(MWAWDocumentInternal::getHeader(ip, rsrcParser, false));
+  std::shared_ptr<MWAWHeader> header(MWAWDocumentInternal::getHeader(ip, rsrcParser, false));
 
   if (!header.get()) return MWAW_R_UNKNOWN_ERROR;
 
-  shared_ptr<MWAWTextParser> parser=MWAWDocumentInternal::getTextParserFromHeader(ip, rsrcParser, header.get());
+  auto parser=MWAWDocumentInternal::getTextParserFromHeader(ip, rsrcParser, header.get());
   if (!parser) return MWAW_R_UNKNOWN_ERROR;
   parser->parse(documentInterface);
 
@@ -434,27 +462,27 @@ namespace MWAWDocumentInternal
 {
 /** return the header corresponding to an input. Or 0L if no input are found */
 MWAWHeader *getHeader(MWAWInputStreamPtr &ip,
-                      MWAWRSRCParserPtr rsrcParser,
+                      MWAWRSRCParserPtr const &rsrcParser,
                       bool strict)
 try
 {
   std::vector<MWAWHeader> listHeaders;
 
-  if (!ip.get()) return 0L;
+  if (!ip.get()) return nullptr;
 
   if (ip->hasDataFork()) {
     /** avoid very short file */
-    if (!ip->hasResourceFork() && ip->size() < 10) return 0L;
+    if (!ip->hasResourceFork() && ip->size() < 10) return nullptr;
 
     ip->seek(0, librevenge::RVNG_SEEK_SET);
     ip->setReadInverted(false);
   }
   else if (!ip->hasResourceFork())
-    return 0L;
+    return nullptr;
 
   listHeaders = MWAWHeader::constructHeader(ip, rsrcParser);
   size_t numHeaders = listHeaders.size();
-  if (numHeaders==0) return 0L;
+  if (numHeaders==0) return nullptr;
 
   for (int step=0; step<2; ++step) {
     for (size_t i = 0; i < numHeaders; i++) {
@@ -464,28 +492,28 @@ try
     }
     if (strict) break;
   }
-  return 0L;
+  return nullptr;
 }
 catch (libmwaw::FileException)
 {
   MWAW_DEBUG_MSG(("MWAWDocumentInternal::MWAWDocument[getHeader]:File exception trapped\n"));
-  return 0L;
+  return nullptr;
 }
 catch (libmwaw::ParseException)
 {
   MWAW_DEBUG_MSG(("MWAWDocumentInternal::getHeader:Parse exception trapped\n"));
-  return 0L;
+  return nullptr;
 }
 catch (...)
 {
   //fixme: too generic
   MWAW_DEBUG_MSG(("MWAWDocumentInternal::getHeader:Unknown exception trapped\n"));
-  return 0L;
+  return nullptr;
 }
 
-shared_ptr<MWAWGraphicParser> getGraphicParserFromHeader(MWAWInputStreamPtr &input, MWAWRSRCParserPtr rsrcParser, MWAWHeader *header)
+std::shared_ptr<MWAWGraphicParser> getGraphicParserFromHeader(MWAWInputStreamPtr &input, MWAWRSRCParserPtr const &rsrcParser, MWAWHeader *header)
 {
-  shared_ptr<MWAWGraphicParser> parser;
+  std::shared_ptr<MWAWGraphicParser> parser;
   if (!header)
     return parser;
   if (header->getKind()!=MWAWDocument::MWAW_K_DRAW && header->getKind()!=MWAWDocument::MWAW_K_PAINT)
@@ -504,6 +532,15 @@ shared_ptr<MWAWGraphicParser> getGraphicParserFromHeader(MWAWInputStreamPtr &inp
       else
         parser.reset(new BeagleWksDRParser(input, rsrcParser, header));
       break;
+    case MWAWDocument::MWAW_T_CANVAS:
+      if (header->getMajorVersion()<=3)
+        parser.reset(new CanvasParser(input, rsrcParser, header));
+      else
+        parser.reset(new Canvas5Parser(input, rsrcParser, header));
+      break;
+    case MWAWDocument::MWAW_T_DRAWINGTABLE:
+      parser.reset(new DrawTableParser(input, rsrcParser, header));
+      break;
     case MWAWDocument::MWAW_T_CLARISDRAW:
       parser.reset(new ClarisDrawParser(input, rsrcParser, header));
       break;
@@ -511,6 +548,9 @@ shared_ptr<MWAWGraphicParser> getGraphicParserFromHeader(MWAWInputStreamPtr &inp
       if (header->getKind()==MWAWDocument::MWAW_K_PAINT)
         parser.reset(new ClarisWksBMParser(input, rsrcParser, header));
       break;
+    case MWAWDocument::MWAW_T_CORELPAINTER:
+      parser.reset(new CorelPainterParser(input, rsrcParser, header));
+      break;
     case MWAWDocument::MWAW_T_CRICKETDRAW:
       parser.reset(new CricketDrawParser(input, rsrcParser, header));
       break;
@@ -550,6 +590,7 @@ shared_ptr<MWAWGraphicParser> getGraphicParserFromHeader(MWAWInputStreamPtr &inp
     case MWAWDocument::MWAW_T_SUPERPAINT:
       parser.reset(new SuperPaintParser(input, rsrcParser, header));
       break;
+
     // TODO: first separate graphic format to other formats, then implement parser...
     case MWAWDocument::MWAW_T_ACTA:
     case MWAWDocument::MWAW_T_ADOBEILLUSTRATOR:
@@ -564,6 +605,7 @@ shared_ptr<MWAWGraphicParser> getGraphicParserFromHeader(MWAWInputStreamPtr &inp
     case MWAWDocument::MWAW_T_FULLIMPACT:
     case MWAWDocument::MWAW_T_FULLWRITE:
     case MWAWDocument::MWAW_T_INFOGENIE:
+    case MWAWDocument::MWAW_T_JAZZLOTUS:
     case MWAWDocument::MWAW_T_KALEIDAGRAPH:
     case MWAWDocument::MWAW_T_HANMACWORDJ:
     case MWAWDocument::MWAW_T_HANMACWORDK:
@@ -597,7 +639,24 @@ shared_ptr<MWAWGraphicParser> getGraphicParserFromHeader(MWAWInputStreamPtr &inp
     case MWAWDocument::MWAW_T_ZWRITE:
     case MWAWDocument::MWAW_T_4DIMENSION:
 
-    case MWAWDocument::MWAW_T_RESERVED9:
+    case MWAWDocument::MWAW_T_RESERVED13:
+    case MWAWDocument::MWAW_T_RESERVED14:
+    case MWAWDocument::MWAW_T_RESERVED15:
+    case MWAWDocument::MWAW_T_RESERVED16:
+    case MWAWDocument::MWAW_T_RESERVED17:
+    case MWAWDocument::MWAW_T_RESERVED18:
+    case MWAWDocument::MWAW_T_RESERVED19:
+    case MWAWDocument::MWAW_T_RESERVED20:
+    case MWAWDocument::MWAW_T_RESERVED21:
+    case MWAWDocument::MWAW_T_RESERVED22:
+    case MWAWDocument::MWAW_T_RESERVED23:
+    case MWAWDocument::MWAW_T_RESERVED24:
+    case MWAWDocument::MWAW_T_RESERVED25:
+    case MWAWDocument::MWAW_T_RESERVED26:
+    case MWAWDocument::MWAW_T_RESERVED27:
+    case MWAWDocument::MWAW_T_RESERVED28:
+    case MWAWDocument::MWAW_T_RESERVED29:
+
     case MWAWDocument::MWAW_T_UNKNOWN:
 #if !defined(__clang__)
     default:
@@ -610,9 +669,9 @@ shared_ptr<MWAWGraphicParser> getGraphicParserFromHeader(MWAWInputStreamPtr &inp
   return parser;
 }
 
-shared_ptr<MWAWPresentationParser> getPresentationParserFromHeader(MWAWInputStreamPtr &input, MWAWRSRCParserPtr rsrcParser, MWAWHeader *header)
+std::shared_ptr<MWAWPresentationParser> getPresentationParserFromHeader(MWAWInputStreamPtr &input, MWAWRSRCParserPtr const &rsrcParser, MWAWHeader *header)
 {
-  shared_ptr<MWAWPresentationParser> parser;
+  std::shared_ptr<MWAWPresentationParser> parser;
   if (!header)
     return parser;
   if (header->getKind()!=MWAWDocument::MWAW_K_PRESENTATION)
@@ -636,11 +695,14 @@ shared_ptr<MWAWPresentationParser> getPresentationParserFromHeader(MWAWInputStre
     case MWAWDocument::MWAW_T_ADOBEILLUSTRATOR:
     case MWAWDocument::MWAW_T_APPLEPICT:
     case MWAWDocument::MWAW_T_BEAGLEWORKS:
+    case MWAWDocument::MWAW_T_CANVAS:
     case MWAWDocument::MWAW_T_CLARISDRAW:
     case MWAWDocument::MWAW_T_CLARISRESOLVE:
+    case MWAWDocument::MWAW_T_CORELPAINTER:
     case MWAWDocument::MWAW_T_CRICKETDRAW:
     case MWAWDocument::MWAW_T_DBASE:
     case MWAWDocument::MWAW_T_DOCMAKER:
+    case MWAWDocument::MWAW_T_DRAWINGTABLE:
     case MWAWDocument::MWAW_T_EDOC:
     case MWAWDocument::MWAW_T_FAMILYTREEMAKER:
     case MWAWDocument::MWAW_T_FILEMAKER:
@@ -653,6 +715,7 @@ shared_ptr<MWAWPresentationParser> getPresentationParserFromHeader(MWAWInputStre
     case MWAWDocument::MWAW_T_GREATWORKS:
     case MWAWDocument::MWAW_T_INFOGENIE:
     case MWAWDocument::MWAW_T_KALEIDAGRAPH:
+    case MWAWDocument::MWAW_T_JAZZLOTUS:
     case MWAWDocument::MWAW_T_HANMACWORDJ:
     case MWAWDocument::MWAW_T_HANMACWORDK:
     case MWAWDocument::MWAW_T_LIGHTWAYTEXT:
@@ -691,7 +754,24 @@ shared_ptr<MWAWPresentationParser> getPresentationParserFromHeader(MWAWInputStre
     case MWAWDocument::MWAW_T_ZWRITE:
     case MWAWDocument::MWAW_T_4DIMENSION:
 
-    case MWAWDocument::MWAW_T_RESERVED9:
+    case MWAWDocument::MWAW_T_RESERVED13:
+    case MWAWDocument::MWAW_T_RESERVED14:
+    case MWAWDocument::MWAW_T_RESERVED15:
+    case MWAWDocument::MWAW_T_RESERVED16:
+    case MWAWDocument::MWAW_T_RESERVED17:
+    case MWAWDocument::MWAW_T_RESERVED18:
+    case MWAWDocument::MWAW_T_RESERVED19:
+    case MWAWDocument::MWAW_T_RESERVED20:
+    case MWAWDocument::MWAW_T_RESERVED21:
+    case MWAWDocument::MWAW_T_RESERVED22:
+    case MWAWDocument::MWAW_T_RESERVED23:
+    case MWAWDocument::MWAW_T_RESERVED24:
+    case MWAWDocument::MWAW_T_RESERVED25:
+    case MWAWDocument::MWAW_T_RESERVED26:
+    case MWAWDocument::MWAW_T_RESERVED27:
+    case MWAWDocument::MWAW_T_RESERVED28:
+    case MWAWDocument::MWAW_T_RESERVED29:
+
     case MWAWDocument::MWAW_T_UNKNOWN:
 #if !defined(__clang__)
     default:
@@ -705,9 +785,9 @@ shared_ptr<MWAWPresentationParser> getPresentationParserFromHeader(MWAWInputStre
 }
 
 /** Factory wrapper to construct a parser corresponding to an spreadsheet header */
-shared_ptr<MWAWSpreadsheetParser> getSpreadsheetParserFromHeader(MWAWInputStreamPtr &input, MWAWRSRCParserPtr rsrcParser, MWAWHeader *header)
+std::shared_ptr<MWAWSpreadsheetParser> getSpreadsheetParserFromHeader(MWAWInputStreamPtr &input, MWAWRSRCParserPtr const &rsrcParser, MWAWHeader *header)
 {
-  shared_ptr<MWAWSpreadsheetParser> parser;
+  std::shared_ptr<MWAWSpreadsheetParser> parser;
   if (!header)
     return parser;
   if (header->getKind()!=MWAWDocument::MWAW_K_SPREADSHEET && header->getKind()!=MWAWDocument::MWAW_K_DATABASE)
@@ -733,29 +813,41 @@ shared_ptr<MWAWSpreadsheetParser> getSpreadsheetParserFromHeader(MWAWInputStream
       else
         parser.reset(new GreatWksDBParser(input, rsrcParser, header));
       break;
+    case MWAWDocument::MWAW_T_JAZZLOTUS:
+      parser.reset(new JazzSSParser(input, rsrcParser, header));
+      break;
+    case MWAWDocument::MWAW_T_MICROSOFTMULTIPLAN:
+      parser.reset(new MultiplanParser(input, rsrcParser, header));
+      break;
     case MWAWDocument::MWAW_T_MICROSOFTWORKS:
       if (header->getKind()==MWAWDocument::MWAW_K_SPREADSHEET)
         parser.reset(new MsWksSSParser(input, rsrcParser, header));
       else
         parser.reset(new MsWksDBParser(input, rsrcParser, header));
       break;
+    case MWAWDocument::MWAW_T_RAGTIME:
+      if (header->getMajorVersion()>=5)
+        parser.reset(new RagTime5SSParser(input, rsrcParser, header));
+      break;
     case MWAWDocument::MWAW_T_WINGZ:
       parser.reset(new WingzParser(input, rsrcParser, header));
       break;
     // TODO
     case MWAWDocument::MWAW_T_FULLIMPACT:
     case MWAWDocument::MWAW_T_KALEIDAGRAPH:
-    case MWAWDocument::MWAW_T_MICROSOFTMULTIPLAN:
     case MWAWDocument::MWAW_T_TRAPEZE:
 
     // no spreadsheet, but some database
     case MWAWDocument::MWAW_T_ACTA:
     case MWAWDocument::MWAW_T_ADOBEILLUSTRATOR:
     case MWAWDocument::MWAW_T_APPLEPICT:
+    case MWAWDocument::MWAW_T_CANVAS:
     case MWAWDocument::MWAW_T_CLARISDRAW:
+    case MWAWDocument::MWAW_T_CORELPAINTER:
     case MWAWDocument::MWAW_T_CRICKETDRAW:
     case MWAWDocument::MWAW_T_DBASE:
     case MWAWDocument::MWAW_T_DOCMAKER:
+    case MWAWDocument::MWAW_T_DRAWINGTABLE:
     case MWAWDocument::MWAW_T_EDOC:
     case MWAWDocument::MWAW_T_FAMILYTREEMAKER:
     case MWAWDocument::MWAW_T_FILEMAKER:
@@ -787,7 +879,6 @@ shared_ptr<MWAWSpreadsheetParser> getSpreadsheetParserFromHeader(MWAWInputStream
     case MWAWDocument::MWAW_T_PAGEMAKER:
     case MWAWDocument::MWAW_T_POWERPOINT:
     case MWAWDocument::MWAW_T_PIXELPAINT:
-    case MWAWDocument::MWAW_T_RAGTIME:
     case MWAWDocument::MWAW_T_READYSETGO:
     case MWAWDocument::MWAW_T_STYLE:
     case MWAWDocument::MWAW_T_SUPERPAINT:
@@ -800,7 +891,24 @@ shared_ptr<MWAWSpreadsheetParser> getSpreadsheetParserFromHeader(MWAWInputStream
     case MWAWDocument::MWAW_T_ZWRITE:
     case MWAWDocument::MWAW_T_4DIMENSION:
 
-    case MWAWDocument::MWAW_T_RESERVED9:
+    case MWAWDocument::MWAW_T_RESERVED13:
+    case MWAWDocument::MWAW_T_RESERVED14:
+    case MWAWDocument::MWAW_T_RESERVED15:
+    case MWAWDocument::MWAW_T_RESERVED16:
+    case MWAWDocument::MWAW_T_RESERVED17:
+    case MWAWDocument::MWAW_T_RESERVED18:
+    case MWAWDocument::MWAW_T_RESERVED19:
+    case MWAWDocument::MWAW_T_RESERVED20:
+    case MWAWDocument::MWAW_T_RESERVED21:
+    case MWAWDocument::MWAW_T_RESERVED22:
+    case MWAWDocument::MWAW_T_RESERVED23:
+    case MWAWDocument::MWAW_T_RESERVED24:
+    case MWAWDocument::MWAW_T_RESERVED25:
+    case MWAWDocument::MWAW_T_RESERVED26:
+    case MWAWDocument::MWAW_T_RESERVED27:
+    case MWAWDocument::MWAW_T_RESERVED28:
+    case MWAWDocument::MWAW_T_RESERVED29:
+
     case MWAWDocument::MWAW_T_UNKNOWN:
 #if !defined(__clang__)
     default:
@@ -814,9 +922,9 @@ shared_ptr<MWAWSpreadsheetParser> getSpreadsheetParserFromHeader(MWAWInputStream
 }
 
 /** Factory wrapper to construct a parser corresponding to an text header */
-shared_ptr<MWAWTextParser> getTextParserFromHeader(MWAWInputStreamPtr &input, MWAWRSRCParserPtr rsrcParser, MWAWHeader *header)
+std::shared_ptr<MWAWTextParser> getTextParserFromHeader(MWAWInputStreamPtr &input, MWAWRSRCParserPtr const &rsrcParser, MWAWHeader *header)
 {
-  shared_ptr<MWAWTextParser> parser;
+  std::shared_ptr<MWAWTextParser> parser;
   if (!header)
     return parser;
   // removeme: actually ClarisWorks draw file are exported as text file
@@ -852,6 +960,9 @@ shared_ptr<MWAWTextParser> getTextParserFromHeader(MWAWInputStreamPtr &input, MW
     case MWAWDocument::MWAW_T_HANMACWORDK:
       parser.reset(new HanMacWrdKParser(input, rsrcParser, header));
       break;
+    case MWAWDocument::MWAW_T_JAZZLOTUS:
+      parser.reset(new JazzWriterParser(input, rsrcParser, header));
+      break;
     case MWAWDocument::MWAW_T_LIGHTWAYTEXT:
       parser.reset(new LightWayTxtParser(input, rsrcParser, header));
       break;
@@ -916,10 +1027,13 @@ shared_ptr<MWAWTextParser> getTextParserFromHeader(MWAWInputStreamPtr &input, MW
 
     case MWAWDocument::MWAW_T_ADOBEILLUSTRATOR:
     case MWAWDocument::MWAW_T_APPLEPICT:
+    case MWAWDocument::MWAW_T_CANVAS:
     case MWAWDocument::MWAW_T_CLARISDRAW:
     case MWAWDocument::MWAW_T_CLARISRESOLVE:
+    case MWAWDocument::MWAW_T_CORELPAINTER:
     case MWAWDocument::MWAW_T_CRICKETDRAW:
     case MWAWDocument::MWAW_T_DBASE:
+    case MWAWDocument::MWAW_T_DRAWINGTABLE:
     case MWAWDocument::MWAW_T_FAMILYTREEMAKER:
     case MWAWDocument::MWAW_T_FILEMAKER:
     case MWAWDocument::MWAW_T_FOXBASE:
@@ -947,7 +1061,24 @@ shared_ptr<MWAWTextParser> getTextParserFromHeader(MWAWInputStreamPtr &input, MW
     case MWAWDocument::MWAW_T_XPRESS:
     case MWAWDocument::MWAW_T_4DIMENSION:
 
-    case MWAWDocument::MWAW_T_RESERVED9:
+    case MWAWDocument::MWAW_T_RESERVED13:
+    case MWAWDocument::MWAW_T_RESERVED14:
+    case MWAWDocument::MWAW_T_RESERVED15:
+    case MWAWDocument::MWAW_T_RESERVED16:
+    case MWAWDocument::MWAW_T_RESERVED17:
+    case MWAWDocument::MWAW_T_RESERVED18:
+    case MWAWDocument::MWAW_T_RESERVED19:
+    case MWAWDocument::MWAW_T_RESERVED20:
+    case MWAWDocument::MWAW_T_RESERVED21:
+    case MWAWDocument::MWAW_T_RESERVED22:
+    case MWAWDocument::MWAW_T_RESERVED23:
+    case MWAWDocument::MWAW_T_RESERVED24:
+    case MWAWDocument::MWAW_T_RESERVED25:
+    case MWAWDocument::MWAW_T_RESERVED26:
+    case MWAWDocument::MWAW_T_RESERVED27:
+    case MWAWDocument::MWAW_T_RESERVED28:
+    case MWAWDocument::MWAW_T_RESERVED29:
+
     case MWAWDocument::MWAW_T_UNKNOWN:
 #if !defined(__clang__)
     default:
@@ -961,10 +1092,10 @@ shared_ptr<MWAWTextParser> getTextParserFromHeader(MWAWInputStreamPtr &input, MW
 }
 
 /** Wrapper to check a basic header of a mac file */
-bool checkBasicMacHeader(MWAWInputStreamPtr &input, MWAWRSRCParserPtr rsrcParser, MWAWHeader &header, bool strict)
+bool checkBasicMacHeader(MWAWInputStreamPtr &input, MWAWRSRCParserPtr const &rsrcParser, MWAWHeader &header, bool strict)
 try
 {
-  shared_ptr<MWAWParser> parser=getTextParserFromHeader(input, rsrcParser, &header);
+  std::shared_ptr<MWAWParser> parser=getTextParserFromHeader(input, rsrcParser, &header);
   if (!parser)
     parser=getSpreadsheetParserFromHeader(input, rsrcParser, &header);
   if (!parser)
