@@ -366,6 +366,8 @@ std::ostream &operator<<(std::ostream &o, Token const &tok)
   case MWAWField::Database:
     o << "field[database],";
     break;
+  case MWAWField::BookmarkStart:
+  case MWAWField::BookmarkEnd:
   case MWAWField::None:
 #if !defined(__clang__)
   default:
@@ -1719,7 +1721,7 @@ bool MsWks4Text::toknDataParser(MWAWInputStreamPtr input, long endPos,
   long actPos = input->tell();
   long length = endPos-actPos;
 
-  if (length < 10) {
+  if (length < 10 || !input->checkPosition(endPos)) {
     mess = "###";
     return true;
   }
