@@ -253,6 +253,9 @@ bool File::readFileInformation()
     checkFInfoType("TEXT","eWorld") || checkFInfoType("ttro","eWorld[readOnly]") ||
     checkFInfoType("eWorld");
   }
+  else if (m_fInfoCreator=="APBP") {
+    checkFInfoType("APBL", "Drawing Table") || checkFInfoType("Drawing Table");
+  }
   else if (m_fInfoCreator=="ARTX") {
     checkFInfoType("RIFF","Corel Painter X") || checkFInfoType("Corel Painter X");
   }
@@ -294,6 +297,13 @@ bool File::readFileInformation()
   else if (m_fInfoCreator=="CRDW") {
     checkFInfoType("CKDT","CricketDraw") || checkFInfoType("CricketDraw");
   }
+  else if (m_fInfoCreator=="DAD2") {
+    checkFInfoType("drw2","Canvas 2-3") || checkFInfoType("Canvas 2-3");
+  }
+  else if (m_fInfoCreator=="DAD5") {
+    checkFInfoType("drw5","Canvas 5") || checkFInfoType("drwt","Canvas 5[template]") ||
+    checkFInfoType("Canvas 5");
+  }
   else if (m_fInfoCreator=="DkmR") {
     checkFInfoType("TEXT","Basic text(created by DOCMaker)") || checkFInfoType("DOCMaker");
   }
@@ -312,6 +322,9 @@ bool File::readFileInformation()
   else if (m_fInfoCreator=="FHA3") {
     checkFInfoType("FHD3","FreeHand 3") || checkFInfoType("FreeHand 3");
   }
+  else if (m_fInfoCreator=="FMPR") {
+    checkFInfoType("FMPR","Claris FileMaker Pro") || checkFInfoType("Claris FileMaker Pro");
+  }
   else if (m_fInfoCreator=="FS03") {
     checkFInfoType("WRT+","WriterPlus") || checkFInfoType("WriterPlus");
   }
@@ -340,6 +353,9 @@ bool File::readFileInformation()
   else if (m_fInfoCreator=="GM01") {
     checkFInfoType("GfMt","MouseWrite") || checkFInfoType("MouseWrite");
   }
+  else if (m_fInfoCreator=="JAZZ") { // Jazz Lotus
+    checkFInfoType("JWKS","Jazz(spreadsheet)") || checkFInfoType("JWPD","Jazz(text)") || checkFInfoType("Jazz");
+  }
   else if (m_fInfoCreator=="JWrt") {
     checkFInfoType("TEXT","JoliWrite") || checkFInfoType("ttro","JoliWrite[readOnly]") ||
     checkFInfoType("JoliWrite");
@@ -365,7 +381,7 @@ bool File::readFileInformation()
     checkFInfoType("ttro","LightWayText[Tutorial]") || checkFInfoType("LightWayText");
   }
   else if (m_fInfoCreator=="LWTR") {
-    checkFInfoType("APPL","LightWayText[appli]");
+    checkFInfoType("APPL","LightWayText[appli]") || checkFInfoType("LightWayText");
   }
   else if (m_fInfoCreator=="MACA") {
     checkFInfoType("WORD","MacWrite") || checkFInfoType("MacWrite");
@@ -381,7 +397,7 @@ bool File::readFileInformation()
     checkFInfoType("MacDraft 4-5");
   }
   else if (m_fInfoCreator=="MDsr") {
-    checkFInfoType("APPL","MacDoc(appli)");
+    checkFInfoType("APPL","MacDoc(appli)") || checkFInfoType("MacDoc");
   }
   else if (m_fInfoCreator=="MDvr") {
     checkFInfoType("MDdc","MacDoc") || checkFInfoType("MacDoc");
@@ -539,7 +555,7 @@ bool File::readFileInformation()
     checkFInfoType("XDOC","QuarkXPress 3-4") ||
     checkFInfoType("XTMP","QuarkXPress 3-4[template]") ||
     checkFInfoType("XBOK","QuarkXPress 4[book]") ||
-    checkFInfoType("XLIB","QuarkXPress 4[library]") ||
+    checkFInfoType("XLIB","QuarkXPress 3-4[library]") ||
     checkFInfoType("QuarkXPress 3-4");
   }
   else if (m_fInfoCreator=="XPRS") {
@@ -569,7 +585,7 @@ bool File::readFileInformation()
     checkFInfoType("eDoc","eDOC") || checkFInfoType("eDOC");
   }
   else if (m_fInfoCreator=="eSRD") {
-    checkFInfoType("APPL","eDOC(appli)");
+    checkFInfoType("APPL","eDOC(appli)") || checkFInfoType("eDOC");
   }
   else if (m_fInfoCreator=="nX^n") {
     checkFInfoType("nX^d","WriteNow 2") || checkFInfoType("nX^2","WriteNow 3-4") ||
@@ -722,6 +738,10 @@ bool File::readDataInformation()
     m_dataResult.push_back("MouseWrite");
     return true;
   }
+  if (val[0]==0x000c && val[1]==0x1357 && (val[2]==0x13 || val[2]==0x14) && val[3]==0) {
+    m_dataResult.push_back("Drawing Table");
+    return true;
+  }
   if (val[0]==0x2550 && val[1]==0x4446) {
     m_dataResult.push_back("PDF");
     return true;
@@ -769,6 +789,10 @@ bool File::readDataInformation()
       return true;
     }
   }
+  if (val[0]==0x200 && val[1]==0x80 && val[2]==0 && val[3]==0 && (val[4]==0 || val[4]==0x800)) {
+    m_dataResult.push_back("Canvas 5");
+    return true;
+  }
   if (val[0]==0xffd8 &&
       ((val[1]==0xffe0 && val[3]==0x4a46 && val[4] == 0x4946) ||
        (val[1]==0xffe1 && val[3]==0x4578 && val[4] == 0x6966) ||
@@ -827,6 +851,22 @@ bool File::readDataInformation()
       return true;
     }
   }
+  if (val[0]==0 && (val[1]==0x4d4d||val[1]==0x4949) && (val[2]==0x5850 || val[2]==0xd850) && (val[3]&0xff00)==0x5200) {
+    if ((val[3]&0xff)==0x33) {
+      if (val[2]==0x5850)
+        m_dataResult.push_back("QuarkXPress 3");
+      else
+        m_dataResult.push_back("QuarkXPress 3[library]");
+      return true;
+    }
+    else if ((val[3]&0xff)==0x61) {
+      if (val[2]==0x5850)
+        m_dataResult.push_back("QuarkXPress 3[khorean]");
+      else
+        m_dataResult.push_back("QuarkXPress 3[khorean,library]");
+      return true;
+    }
+  }
   if ((val[0]==0x100||val[0]==0x200) && val[2]==0x4558 && val[3]==0x5057) {
     if (val[0]==0x100)
       m_dataResult.push_back("ClarisDraw");
@@ -876,6 +916,10 @@ bool File::readDataInformation()
     m_dataResult.push_back("MacWrite II");
   if (val[0] == 4 && val[1] == 4)
     m_dataResult.push_back("MacWrite Pro");
+  if (val[0] == 0x20 && val[1] == 0x20)
+    m_dataResult.push_back("QuarkXpress 1");
+  if (val[0] == 0x26 && val[1] == 0x26)
+    m_dataResult.push_back("QuarkXpress 2");
   if (val[0] == 0x7704)
     m_dataResult.push_back("MindWrite");
   if (val[0] == 0x110)
@@ -908,6 +952,8 @@ bool File::readDataInformation()
     if (val[numParaPos] < 0x1000 && val[numParaPos+1] < 0x100 && val[numParaPos+2] < 0x100)
       m_dataResult.push_back("MacWrite[unsure]");
   }
+  if (val[0]==0 && val[1]==2 && val[2]==11)
+    m_dataResult.push_back("Jazz(spreadsheet)[unsure]");
   if (val[0]==0) {
     std::stringstream s;
     bool ok = true;
